==> generator-ng-poly-0.12.2.tgz: package/generators/element/index.js <==
'use strict';

require('babel-polyfill');

var _genBase = require('../genBase');

var _genBase2 = _interopRequireDefault(_genBase);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pify = require('pify');

var _pify2 = _interopRequireDefault(_pify);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = _genBase2.default.extend({
  writing: function writing() {
    var done, config, elementDir;
    return regeneratorRuntime.async(function writing$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            done = this.async();
            _context.next = 3;
            return regeneratorRuntime.awrap(this.getConfig());

          case 3:
            config = _context.sent;
            elementDir = _path2.default.join(config.appDir, 'components', config.hyphenName);
            _context.next = 7;
            return regeneratorRuntime.awrap((0, _pify2.default)(_mkdirp2.default)(elementDir));

          case 7:

            if (config.appScript === 'ts') {
              config.referencePath = _path2.default.relative(elementDir, config.appDir);
              config.appScript = 'js';
            }

            _context.next = 10;
            return regeneratorRuntime.awrap(Promise.all([this.copyStyleFile('element', _path2.default.join(elementDir, config.hyphenName + '.' + config.style), config), this.copyMarkupFile('element', _path2.default.join(elementDir, config.hyphenName + '.' + config.markup), config), this.copySrcFile('element', _path2.default.join(elementDir, config.hyphenName + '.' + config.appScript), config)]));

          case 10:

            done();

          case 11:
          case 'end':
            return _context.stop();
        }
      }
    }, null, this);
  }
});

==> generator-ng-poly-0.13.0.tgz: package/generators/element/index.js <==
'use strict';

require('babel-polyfill');

var _genBase = require('../genBase');

var _genBase2 = _interopRequireDefault(_genBase);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pify = require('pify');

var _pify2 = _interopRequireDefault(_pify);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = _genBase2.default.extend({
  writing: function writing() {
    var config, elementDir;
    return regeneratorRuntime.async(function writing$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return regeneratorRuntime.awrap(this.getConfig());

          case 2:
            config = _context.sent;
            elementDir = _path2.default.join(config.appDir, 'components', config.hyphenName);
            _context.next = 6;
            return regeneratorRuntime.awrap((0, _pify2.default)(_mkdirp2.default)(elementDir));

          case 6:

            if (config.appScript === 'ts') {
              config.referencePath = _path2.default.relative(elementDir, config.appDir);
              config.appScript = 'js';
            }

            return _context.abrupt('return', Promise.all([this.copyStyleFile('element', _path2.default.join(elementDir, config.hyphenName + '.' + config.style), config), this.copyMarkupFile('element', _path2.default.join(elementDir, config.hyphenName + '.' + config.markup), config), this.copySrcFile('element', _path2.default.join(elementDir, config.hyphenName + '.' + config.appScript), config)]));

          case 8:
          case 'end':
            return _context.stop();
        }
      }
    }, null, this);
  }
});
